@@ -77,8 +77,7 @@ style = {
         ],
     ),
     "axes.titlepad": 40,
-    "axes.titlesize": 18,
-    "axes.titlelocation": "left",
+    "axes.titlesize": 14,
 }
 
 style_bar = style.copy()
@@ -87,6 +86,11 @@ style_bar["xtick.major.width"] = 0
 # unhide the bar labels
 style_bar["xtick.major.pad"] = 13
 style_bar["font.size"] = 16
+# default:
+style_bar["axes.xmargin"] = mpl.rcParams["axes.xmargin"]
+# style_bar["ytick.major.size"] = 10
+style_bar["axes.titlelocation"] = "left"
+style_bar["axes.titlesize"] = 18
 
 
 def _move_min_distance(targets, min_distance):
@@ -113,21 +117,18 @@ def _move_min_distance(targets, min_distance):
 
     # reorder
     idx2 = np.argsort(idx)
-    sol = sol[idx2]
-
-    return sol
+    return sol[idx2]
 
 
 def legend(ax=None, min_label_distance="auto", alpha: float = 1.0):
     ax = ax or plt.gca()
 
-    fig = plt.gcf()
-
     logy = ax.get_yscale() == "log"
 
     if min_label_distance == "auto":
         # Make sure that the distance is alpha * fontsize. This needs to be translated
         # into axes units.
+        fig = plt.gcf()
         fig_height_inches = fig.get_size_inches()[1]
         ax = plt.gca()
         ax_pos = ax.get_position()
@@ -140,31 +141,33 @@ def legend(ax=None, min_label_distance="auto", alpha: float = 1.0):
             ax_height_ylim = ylim[1] - ylim[0]
         # 1 pt = 1/72 in
         fontsize = mpl.rcParams["font.size"]
+        assert fontsize is not None
         min_label_distance_inches = fontsize / 72 * alpha
         min_label_distance = (
             min_label_distance_inches / ax_height_inches * ax_height_ylim
         )
 
-    # find all Line2D objects with a valid label
-    lines = []
-    for child in ax.get_children():
-        if isinstance(child, mpl.lines.Line2D):
-            # https://stackoverflow.com/q/64358117/353337
-            if child.get_label()[0] != "_":
-                lines.append(child)
+    # find all Line2D objects with a valid label and valid data
+    lines = [
+        child
+        for child in ax.get_children()
+        # https://stackoverflow.com/q/64358117/353337
+        if (
+            isinstance(child, mpl.lines.Line2D)
+            and child.get_label()[0] != "_"
+            and not np.all(np.isnan(child.get_ydata()))
+        )
+    ]
+
+    if len(lines) == 0:
+        return
 
     # Add "legend" entries.
     # Get last non-nan y-value.
     targets = []
     for line in lines:
         ydata = line.get_ydata()
-        if np.all(np.isnan(ydata)):
-            targets.append(np.nan)
-        else:
-            targets.append(ydata[~np.isnan(ydata)][-1])
-
-    if not targets:
-        return
+        targets.append(ydata[~np.isnan(ydata)][-1])
 
     if logy:
         targets = [math.log10(t) for t in targets]
@@ -218,7 +221,9 @@ def ylabel(string):
     # and
     # <https://github.com/matplotlib/matplotlib/issues/20677>
     yticks = ax.yaxis.get_major_ticks()
-    if len(yticks) > 0:
+    if len(yticks) == 0:
+        pos_x = 0.0
+    else:
         pad_pt = yticks[-1].get_pad()
         # https://stackoverflow.com/a/51213884/353337
         # ticklen_pt = ax.yaxis.majorTicks[0].tick1line.get_markersize()
@@ -228,13 +233,11 @@ def ylabel(string):
         # https://stackoverflow.com/a/19306776/353337
         bbox = ax.get_window_extent().transformed(plt.gcf().dpi_scale_trans.inverted())
         pos_x = -dist_in / bbox.width
-    else:
-        pos_x = 0.0
 
-    ylabel = plt.ylabel(string, horizontalalignment="right", multialignment="right")
+    yl = plt.ylabel(string, horizontalalignment="right", multialignment="right")
     # place the label 10% above the top tick
     ax.yaxis.set_label_coords(pos_x, pos_y)
-    ylabel.set_rotation(0)
+    yl.set_rotation(0)
 
 
 def show_bar_values(fmt="{}"):
@@ -244,6 +247,9 @@ def show_bar_values(fmt="{}"):
     plt.tick_params(axis="y", which="both", left=False, right=False, labelleft=False)
     plt.grid(False)
 
+    # remove margins
+    plt.margins(x=0)
+
     data_to_axis = ax.transData + ax.transAxes.inverted()
     axis_to_data = ax.transAxes + ax.transData.inverted()
 
